summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/objectnamelist.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kstars/kstars/objectnamelist.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/objectnamelist.h')
-rw-r--r--kstars/kstars/objectnamelist.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kstars/kstars/objectnamelist.h b/kstars/kstars/objectnamelist.h
index 691311ee..ea19f621 100644
--- a/kstars/kstars/objectnamelist.h
+++ b/kstars/kstars/objectnamelist.h
@@ -71,7 +71,7 @@ class ObjectNameList {
*@return pointer to the first object in the selected list.
*@param name the name to use in selecting a list.
*/
- SkyObjectName* first(const TQString &name = TQString::null);
+ SkyObjectName* first(const TQString &name = TQString());
/**Returns next object in the currently selected list.
*@return pointer to the next object in the current list, or NULL if
@@ -87,13 +87,13 @@ class ObjectNameList {
*@param name name of object to find.
*@return pointer to object with the given name
*/
- SkyObjectName* find(const TQString &name = TQString::null);
+ SkyObjectName* tqfind(const TQString &name = TQString());
/**@short remove the named object from the list.
*@param name the name of the object to be removed.
*@note If the object is not found, then nothing happens.
*/
- void remove( const TQString &name = TQString::null );
+ void remove( const TQString &name = TQString() );
/**Define the language which should be used for constellation names
*/
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
*It's needed for find(). first() and find() call this function.
*/
void sort();
@@ -128,7 +128,7 @@ class ObjectNameList {
*of the list itself.
*@param name the name of the object whose index is to be found
*/
- int getIndex( const TQString &name = TQString::null );
+ int getIndex( const TQString &name = TQString() );
/**Two modes are available:
*allLists = loop through the whole list if next() is called
@@ -118,7 +118,7 @@ class ObjectNameList {
private:
/**Sorts the lists with objects for faster access.
- *It's needed for find(). first() and find() call this function.
+ *It's needed for tqfind(). first() and tqfind() call this function.
*/
void sort();